@@ -251,9 +251,6 @@ void ScreenSaver::lockScreen()
 {
     Q_D(ScreenSaver);
     if (!d->isScreenSaverLocked()) {
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-        d->m_lockProcess->start(d->lock_command);
-#else
         QStringList args = QProcess::splitCommand(d->lock_command);
         if (args.isEmpty()) {
             qWarning() << Q_FUNC_INFO << "Empty screen lock_command";
@@ -261,7 +258,6 @@ void ScreenSaver::lockScreen()
         }
         const QString program = args.takeFirst();
         d->m_lockProcess->start(program, args, QIODevice::ReadWrite);
-#endif
     }
 }
 
