@@ -12,137 +12,137 @@
 <context>
     <name>LXQt::MessageBox</name>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="75"/>
+        <location filename="../lxqtpowermanager.cpp" line="76"/>
         <source>LXQt Power Manager Error</source>
         <translation>LXQt Güç Yöneticisi Hatası</translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="75"/>
+        <location filename="../lxqtpowermanager.cpp" line="76"/>
         <source>Hibernate failed.</source>
-        <translation>Uykuya alma başarısız oldu.</translation>
+        <translation>Hazırda bekletme başarısız oldu.</translation>
     </message>
 </context>
 <context>
     <name>LXQt::NotificationPrivate</name>
     <message>
-        <location filename="../lxqtnotification.cpp" line="154"/>
+        <location filename="../lxqtnotification.cpp" line="163"/>
         <source>Notifications Fallback</source>
-        <translation>Bildirimleri Geriye Al</translation>
+        <translation>Bildirimleri Geri Al</translation>
     </message>
 </context>
 <context>
     <name>LXQt::PowerManager</name>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="118"/>
+        <location filename="../lxqtpowermanager.cpp" line="108"/>
         <source>Hibernate</source>
-        <translation>Uykuya Al</translation>
+        <translation>Hazırda Beklet</translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="125"/>
+        <location filename="../lxqtpowermanager.cpp" line="115"/>
         <source>Suspend</source>
-        <translation>Beklemeye Al</translation>
+        <translation>Askıya Al</translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="132"/>
+        <location filename="../lxqtpowermanager.cpp" line="122"/>
         <source>Reboot</source>
         <translation>Yeniden Başlat</translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="139"/>
+        <location filename="../lxqtpowermanager.cpp" line="129"/>
         <source>Shutdown</source>
         <translation>Bilgisayarı Kapat</translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="146"/>
+        <location filename="../lxqtpowermanager.cpp" line="136"/>
         <source>Logout</source>
-        <translation>Oturumu Kapat</translation>
+        <translation>Oturumdan Çık</translation>
+    </message>
+    <message>
+        <location filename="../lxqtpowermanager.cpp" line="148"/>
+        <source>LXQt Session Suspend</source>
+        <translation>LXQt Oturumunu Askıya Al</translation>
+    </message>
+    <message>
+        <location filename="../lxqtpowermanager.cpp" line="149"/>
+        <source>Do you want to really suspend your computer?&lt;p&gt;Suspends the computer into a low power state. System state is not preserved if the power is lost.</source>
+        <translation>Bilgisayarınızı askıya almayı gerçekten istiyor musunuz?&lt;p&gt;Bilgisayarı düşük güç tüketiminde askıya alır. Güç biterse sistem durumu korunmaz.</translation>
     </message>
     <message>
         <location filename="../lxqtpowermanager.cpp" line="158"/>
-        <source>LXQt Session Suspend</source>
-        <translation>LXQt Oturumunu Beklemeye Al</translation>
+        <source>LXQt Session Hibernate</source>
+        <translation>LXQt Oturumunu Hazırda Beklet</translation>
     </message>
     <message>
         <location filename="../lxqtpowermanager.cpp" line="159"/>
-        <source>Do you want to really suspend your computer?&lt;p&gt;Suspends the computer into a low power state. System state is not preserved if the power is lost.</source>
-        <translation>Bilgisayarınızı gerçekten beklemeye almak istiyor musunuz?&lt;p&gt;Bilgisayarı düşük güç tüketiminde beklemeye alır. Güç biterse sistem durumu muhafaza edilmez.</translation>
+        <source>Do you want to really hibernate your computer?&lt;p&gt;Hibernates the computer into a low power state. System state is preserved if the power is lost.</source>
+        <translation>Bilgisayarınızı hazırda bekletmeyi gerçekten istiyor musunuz?&lt;p&gt;Bilgisayarı düşük güç tüketiminde hazırda bekletir. Güç biterse sistem durumu korunur.</translation>
     </message>
     <message>
         <location filename="../lxqtpowermanager.cpp" line="168"/>
-        <source>LXQt Session Hibernate</source>
-        <translation>LXQt Oturumunu Uykuya Al</translation>
-    </message>
-    <message>
-        <location filename="../lxqtpowermanager.cpp" line="169"/>
-        <source>Do you want to really hibernate your computer?&lt;p&gt;Hibernates the computer into a low power state. System state is preserved if the power is lost.</source>
-        <translation>Bilgisayarınızı gerçekten uyku kipine geçirmek istiyor musunuz?&lt;p&gt;Bilgisayarı düşük güç tüketiminde uyku kipine alır. Güç biterse sistem durumu muhafaza edilir.</translation>
-    </message>
-    <message>
-        <location filename="../lxqtpowermanager.cpp" line="178"/>
         <source>LXQt Session Reboot</source>
         <translation>LXQt Oturumunu Yeniden Başlat</translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="179"/>
+        <location filename="../lxqtpowermanager.cpp" line="169"/>
         <source>Do you want to really restart your computer? All unsaved work will be lost...</source>
-        <translation>Bilgisayarınızı gerçekten yeniden başlatmak istiyor musunuz? Kaydedilmemiş veriler kaybolacaktır...</translation>
+        <translation>Bilgisayarınızı yeniden başlatmayı gerçekten istiyor musunuz? Kaydedilmemiş veriler kaybolacaktır...</translation>
+    </message>
+    <message>
+        <location filename="../lxqtpowermanager.cpp" line="178"/>
+        <source>LXQt Session Shutdown</source>
+        <translation>LXQt Oturumunu Kapat</translation>
+    </message>
+    <message>
+        <location filename="../lxqtpowermanager.cpp" line="179"/>
+        <source>Do you want to really switch off your computer? All unsaved work will be lost...</source>
+        <translation>Bilgisayarınızı kapatmayı gerçekten istiyor musunuz? Kaydedilmemiş veriler kaybolacaktır...</translation>
     </message>
     <message>
         <location filename="../lxqtpowermanager.cpp" line="188"/>
-        <source>LXQt Session Shutdown</source>
-        <translation>LXQt Bilgisayarı Kapat</translation>
-    </message>
-    <message>
-        <location filename="../lxqtpowermanager.cpp" line="189"/>
-        <source>Do you want to really switch off your computer? All unsaved work will be lost...</source>
-        <translation>Bilgisayarınızı gerçekten kapatmak istiyor musunuz? Kaydedilmemiş veriler kaybolacaktır...</translation>
-    </message>
-    <message>
-        <location filename="../lxqtpowermanager.cpp" line="198"/>
         <source>LXQt Session Logout</source>
         <translation>LXQt Oturumundan Çık</translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="199"/>
+        <location filename="../lxqtpowermanager.cpp" line="189"/>
         <source>Do you want to really logout? All unsaved work will be lost...</source>
-        <translation>Oturumunuzdan gerçekten çıkmak istiyor musunuz? Kaydedilmemiş veriler kaybolacaktır...</translation>
+        <translation>Oturumdan çıkmayı gerçekten istiyor musunuz? Kaydedilmemiş veriler kaybolacaktır...</translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="207"/>
-        <location filename="../lxqtpowermanager.cpp" line="212"/>
+        <location filename="../lxqtpowermanager.cpp" line="197"/>
+        <location filename="../lxqtpowermanager.cpp" line="202"/>
         <source>LXQt Power Manager Error</source>
         <translation>LXQt Güç Yöneticisi Hatası</translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="207"/>
+        <location filename="../lxqtpowermanager.cpp" line="197"/>
         <source>Hibernate failed.</source>
-        <translation>Uykuya alma başarısız oldu.</translation>
+        <translation>Hazırda bekletme başarısız oldu.</translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="212"/>
+        <location filename="../lxqtpowermanager.cpp" line="202"/>
         <source>Suspend failed.</source>
-        <translation>Beklemeye alma başarısız oldu.</translation>
+        <translation>Askıya alma başarısız oldu.</translation>
     </message>
 </context>
 <context>
     <name>LXQt::ScreenSaver</name>
     <message>
-        <location filename="../lxqtscreensaver.cpp" line="161"/>
+        <location filename="../lxqtscreensaver.cpp" line="160"/>
         <source>Failed to run  &quot;%1&quot;. Ensure you have a locker/screensaver compatible with xdg-screensaver installed and running.</source>
-        <translation>&quot;%1&quot; çalıştırma başarısız. xdg-screensaver ile uyumlu bir kilit/ekran koruyucu yüklediğinizden ve çalıştığından emin olun.</translation>
+        <translation>&quot;%1&quot; çalıştırması başarısız. xdg-screensaver ile uyumlu bir kilitleyici/ekran koruyucu yüklediğinizden ve çalıştırdığınızdan emin olunuz.</translation>
     </message>
     <message>
-        <location filename="../lxqtscreensaver.cpp" line="165"/>
+        <location filename="../lxqtscreensaver.cpp" line="164"/>
         <source>Failed to run  &quot;%1&quot;. Ensure the specified locker/screensaver is installed and running.</source>
-        <translation>&quot;%1&quot; çalıştırma başarısız. Belirli bir kilit/ekran koruyucu yüklediğinizden ve çalıştığından emin olun.</translation>
+        <translation>&quot;%1&quot; çalıştırma başarısız. Belirli bir kilitleyicinin/ekran koruyucunun yüklendiğinden ve çalıştığından emin olunuz.</translation>
     </message>
     <message>
-        <location filename="../lxqtscreensaver.cpp" line="243"/>
+        <location filename="../lxqtscreensaver.cpp" line="242"/>
         <source>Lock Screen</source>
         <translation>Ekranı Kilitle</translation>
     </message>
     <message>
-        <location filename="../lxqtscreensaver.cpp" line="156"/>
+        <location filename="../lxqtscreensaver.cpp" line="155"/>
         <source>Screen Saver Error</source>
         <translation>Ekran Koruyucu Hatası</translation>
     </message>
@@ -152,7 +152,7 @@
     <message>
         <location filename="../configdialog/lxqtconfigdialogcmdlineoptions.cpp" line="49"/>
         <source>Choose the page to be shown.</source>
-        <translation>Gösterilecek sayfayı seçin.</translation>
+        <translation>Gösterilecek sayfayı seçiniz.</translation>
     </message>
 </context>
 <context>
