@@ -129,12 +129,12 @@
     <message>
         <location filename="../lxqtscreensaver.cpp" line="160"/>
         <source>Failed to run  &quot;%1&quot;. Ensure you have a locker/screensaver compatible with xdg-screensaver installed and running.</source>
-        <translation type="unfinished"></translation>
+        <translation>無法執行「%1」。請確認是否有安裝與 xdg-screensaver 相容的鎖定程式/螢幕保護程式，並確認其可以執行。</translation>
     </message>
     <message>
         <location filename="../lxqtscreensaver.cpp" line="164"/>
         <source>Failed to run  &quot;%1&quot;. Ensure the specified locker/screensaver is installed and running.</source>
-        <translation type="unfinished"></translation>
+        <translation>無法執行「%1」。請確認是否已安裝指定的鎖定程式/螢幕保護程式，並確認其可以執行。</translation>
     </message>
     <message>
         <location filename="../lxqtscreensaver.cpp" line="242"/>
